@@ -6,7 +6,7 @@ use Carp;
 
 require Exporter;
 
-our $VERSION = '0.20_03';
+our $VERSION = '0.20_04';
 our $XS_VERSION = $VERSION;
 $VERSION = eval $VERSION; # so "use Module 0.002" won't warn on underscore
 
@@ -27,13 +27,13 @@ isnan isnormal isprint ispunct isspace isunordered isupper isxdigit j0 j1 jn
 jrand48 killpg l64a ldexp lgamma link linkat log log1p log2 logb lrand48
 lround lstat mkdir mkdirat mkdtemp mkfifo mkfifoat mknod mknodat mkstemp
 mrand48 nanosleep nearbyint nextafter nice nrand48 open openat openat2 pread
-preadv ptsname pwrite pwritev random read readlink readlinkat readv realpath
-remainder remove remquo rename renameat rmdir round scalbn seed48 setegid
-seteuid setgid setitimer setpriority setregid setreuid setsid setuid setutxent
-sighold sigignore signbit sigpause sigrelse sin sinh srand48 srandom stat
-strptime symlink symlinkat sync tan tanh tgamma timer_create timer_delete
-timer_getoverrun timer_gettime timer_settime trunc truncate ttyname unlink
-unlinkat utimensat write writev y0 y1 yn
+preadv preadv2 ptsname pwrite pwritev pwritev2 random read readlink readlinkat
+readv realpath remainder remove remquo rename renameat rmdir round scalbn
+seed48 setegid seteuid setgid setitimer setpriority setregid setreuid setsid
+setuid setutxent sighold sigignore signbit sigpause sigrelse sin sinh srand48
+srandom stat strptime symlink symlinkat sync tan tanh tgamma timer_create
+timer_delete timer_getoverrun timer_gettime timer_settime trunc truncate
+ttyname unlink unlinkat utimensat write writev y0 y1 yn
 );
 
 our @_constants = qw(
@@ -57,10 +57,11 @@ O_TMPFILE O_TRUNC O_TTY_INIT O_WRONLY OLD_TIME POSIX_FADV_NORMAL
 POSIX_FADV_SEQUENTIAL POSIX_FADV_RANDOM POSIX_FADV_NOREUSE POSIX_FADV_WILLNEED
 POSIX_FADV_DONTNEED PRIO_PROCESS PRIO_PGRP PRIO_USER RESOLVE_BENEATH
 RESOLVE_IN_ROOT RESOLVE_NO_MAGICLINKS RESOLVE_NO_SYMLINKS RESOLVE_NO_XDEV
-RESOLVE_CACHED RTLD_GLOBAL RTLD_LAZY RTLD_LOCAL RTLD_NOW RUN_LVL S_IFMT
-S_IFBLK S_IFCHR S_IFIFO S_IFREG S_IFDIR S_IFLNK S_IFSOCK S_ISUID S_ISGID
-S_IRWXU S_IRUSR S_IWUSR S_IXUSR S_IRWXG S_IRGRP S_IWGRP S_IXGRP S_IRWXO
-S_IROTH S_IWOTH S_IXOTH S_ISVTX SEEK_SET SEEK_CUR SEEK_END TIMER_ABSTIME
+RESOLVE_CACHED RTLD_GLOBAL RTLD_LAZY RTLD_LOCAL RTLD_NOW RUN_LVL RWF_DSYNC
+RWF_HIPRI RWF_SYNC RWF_NOWAIT RWF_APPEND S_IFMT S_IFBLK S_IFCHR S_IFIFO
+S_IFREG S_IFDIR S_IFLNK S_IFSOCK S_ISUID S_ISGID S_IRWXU S_IRUSR S_IWUSR
+S_IXUSR S_IRWXG S_IRGRP S_IWGRP S_IXGRP S_IRWXO S_IROTH S_IWOTH S_IXOTH
+S_ISVTX SEEK_SET SEEK_CUR SEEK_END SEEK_DATA SEEK_HOLE TIMER_ABSTIME
 USER_PROCESS UTIME_NOW UTIME_OMIT F_OK R_OK W_OK X_OK
 );
 
@@ -77,7 +78,7 @@ our %EXPORT_TAGS = (
   'id'     => [grep /^[gs]et.+id$/, @_functions],
   'is'     => [grep /^is/, @_functions],
   'rw'     => [qw(read write readv writev)],
-  'prw'    => [qw(pread preadv pwrite pwritev)],
+  'prw'    => [qw(pread preadv preadv2 pwrite pwritev pwritev2)],
   'clock'  => [grep(/^CLOCK_/, @_constants), grep(/^clock/, @_functions)],
   'fcntl'  => [grep /^(?:[FORWX]|FD|POSIX_FADV|SEEK)_/, @_constants],
   'fnm'    => [grep(/^FNM_/, @_constants), 'fnmatch'],
